smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl

# ``smartcard`.`wx`.`CardAndReaderTreePanel`.`CardTreeCtrl``

class documentation

`class CardTreeCtrl(BaseCardTreeCtrl):`

View In Hierarchy

The CardTreeCtrl monitors inserted cards and notifies the application client dialog of any card activation.

Method | `__init__` | Constructor. Create a smartcard tree control.
Method | `OnAddCards` | Called when a card is inserted. Adds a smart card to the smartcards tree.
Method | `OnRemoveCards` | Called when a card is removed. Removes a card from the tree.
Instance Variable | `root` | Undocumented

Inherited from `BaseCardTreeCtrl`:

Method | `Repaint` | Undocumented
Instance Variable | `capindex` | Undocumented
Instance Variable | `cardimageindex` | Undocumented
Instance Variable | `clientpanel` | Undocumented
Instance Variable | `fldrindex` | Undocumented
Instance Variable | `fldropenindex` | Undocumented
Instance Variable | `il` | Undocumented
Instance Variable | `parent` | Undocumented
Instance Variable | `readerimageindex` | Undocumented

def __init__(self, parent, ID=wx.NewId(), pos=wx.DefaultPosition, size=wx.DefaultSize, style=0, clientpanel=None):
overrides `smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.__init__`

Constructor. Create a smartcard tree control.

def OnAddCards(self, addedcards):

Called when a card is inserted. Adds a smart card to the smartcards tree.

def OnRemoveCards(self, removedcards):

Called when a card is removed. Removes a card from the tree.

root =

Undocumented